@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11774 2019-11-05 06:26:48Z Lavender $
+# $Id: forms.py 11781 2019-11-19 11:15:37Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-11-05 15:26:48 +0900 (週二, 05 十一月 2019) $
-# $Revision: 11774 $
+# $Date: 2019-11-19 20:15:37 +0900 (週二, 19 十一月 2019) $
+# $Revision: 11781 $
 
 import os
 import re
@@ -35,7 +35,7 @@ from oscar.forms.widgets import DatePickerInput
 from oscar.core.utils import datetime_combine
 from ckeditor_uploader.widgets import CKEditorUploadingWidget
 
-from Iuno.shop.models import OrdererAddress
+from Iuno.shop.models import OrdererAddress, BonusSettings
 
 (RelatedFieldWidgetWrapper,
  ) = get_classes(
@@ -608,4 +608,19 @@ if VERSION >= (2, 0, 0):
     basket_tags.AddToBasketForm = AddToBasketForm
     basket_tags.SimpleAddToBasketForm = SimpleAddToBasketForm
     
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3285#ticket
+class BonusSettingsForm(forms.ModelForm):
+    class Meta:
+        model = BonusSettings
+        fields = ['consumption', 'percent', 'discount', 'limit']
+        
+class BonusForm(forms.Form):
+    quantity = forms.IntegerField(
+        label=_("Quantity"), min_value=0)
+        
+    def __init__(self):
+        super().__init__()
+        
 
+        
+    
