@@ -5,7 +5,9 @@
 from django.db import models
 from django.core import exceptions
 from django.contrib.auth import get_user_model
+from django.core.validators import MaxValueValidator, MinValueValidator
 from django.utils.translation import gettext_lazy as _
+from solo.models import SingletonModel
 from oscar.core.loading import get_model
 
 User = get_user_model()
@@ -157,19 +159,25 @@ class BonusRecord(models.Model):
     
 @property
 def bonusRecords(self):
-    return BonusRecord.objects.filter(user=self)
+    return BonusRecord.objects.filter(user=self).order_by('-createdTime')
     
 User.bonusRecords = bonusRecords    
     
-class BonusSettings(models.Model):
+class BonusSettings(SingletonModel):
     consumption = models.PositiveIntegerField(
         verbose_name=_("Consumption exceed"), default=0)
-    percent = models.PositiveIntegerField(
-        verbose_name=_("Percent of consumption turn into bouns"), default=0)
-    discount = models.PositiveIntegerField(
-        verbose_name=_("Discount per bonus"), default=0)
-    limit = models.PositiveIntegerField(
-        verbose_name=_("Dividend use cap"), default=0)
+    percent = models.FloatField(
+        verbose_name=_("Percent of consumption turn into bouns"), default=0.0,
+        validators=[MinValueValidator(0.0),],
+    )
+    discount = models.FloatField(
+        verbose_name=_("Discount per bonus"), default=0.0, 
+        validators=[MinValueValidator(0.0),],
+    )
+    limit = models.IntegerField(
+        verbose_name=_("Dividend use cap(-1 is no limit)"), default=-1,
+        validators=[MinValueValidator(-1),],
+    )
     
     
 class ECPayTrade(models.Model):
