@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11784 2019-11-28 09:39:09Z Lavender $
+# $Id: views.py 11786 2019-12-03 13:14:41Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-11-28 18:39:09 +0900 (週四, 28 十一月 2019) $
-# $Revision: 11784 $ 
+# $Date: 2019-12-03 22:14:41 +0900 (週二, 03 十二月 2019) $
+# $Revision: 11786 $ 
 
 import json
 import logging
@@ -272,7 +272,7 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
         
         # bonus        
         if user.is_authenticated:
-            b = Bonus.objects.get(user=user)
+            b, created = Bonus.objects.get_or_create(user=user)
             config = BonusSettings.objects.get(id=1)
             
             # receive
